"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fastify_1 = require("fastify");
const jsf = require("json-schema-faker");
const __1 = require("..");
describe('pubsub-handler', () => {
    const handler = jest.fn();
    let server;
    afterAll(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        yield server.fastify.close();
    }));
    it('should construct', () => {
        server = __1.createPubSubHandler(handler);
        expect(server).toBeTruthy();
    });
    it('should forward requests', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        server = __1.createPubSubHandler(handler, { parseJson: true });
        const payload = jsf.generate(__1.PubSubMessage);
        payload.message.data = Buffer.from(JSON.stringify({})).toString('base64');
        yield server.fastify.inject({
            method: 'POST',
            url: '/',
            payload,
        });
        expect(handler).toHaveBeenCalled();
    }));
    it('should start listening', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        server = __1.createPubSubHandler(handler, { port: 8123 });
        server.fastify.listen = jest.fn();
        server.fastify.ready(() => server.fastify.close());
        yield server.listen();
        expect(server.fastify.listen).toHaveBeenCalled();
    }));
    it('should parse simple text', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        server = __1.createPubSubHandler(handler, { parseJson: false });
        const payload = jsf.generate(__1.PubSubMessage);
        payload.message.data = Buffer.from(JSON.stringify('hello-world')).toString('base64');
        yield server.fastify.inject({
            method: 'POST',
            url: '/',
            payload,
        });
        expect(handler).toHaveBeenCalled();
    }));
    it('should return status code', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const successHandler = jest.fn(() => ({ statusCode: 200 }));
        server = __1.createPubSubHandler(successHandler, { parseJson: false });
        const payload = jsf.generate(__1.PubSubMessage);
        payload.message.data = Buffer.from(JSON.stringify('hello-world')).toString('base64');
        const { statusCode } = yield server.fastify.inject({
            method: 'POST',
            url: '/',
            payload,
        });
        expect(successHandler).toHaveBeenCalled();
        expect(statusCode).toBe(200);
    }));
    it('should handle env vars', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        process.env.PORT = '8124';
        server = __1.createPubSubHandler(handler);
        server.fastify.listen = jest.fn();
        server.fastify.ready(() => server.fastify.close());
        yield server.listen();
        expect(server.fastify.listen).toHaveBeenCalledWith('8124', '0.0.0.0');
    }));
    it('should be possible to configure port', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        server = __1.createPubSubHandler(handler, { port: 8120 });
        server.fastify.listen = jest.fn();
        server.fastify.ready(() => server.fastify.close());
        yield server.listen();
        expect(server.fastify.listen).toHaveBeenCalledWith(8120, '0.0.0.0');
    }));
    it('should be possible to configure address', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        server = __1.createPubSubHandler(handler, { port: 8120, address: '127.0.0.1' });
        server.fastify.listen = jest.fn();
        server.fastify.ready(() => server.fastify.close());
        yield server.listen();
        expect(server.fastify.listen).toHaveBeenCalledWith(8120, '127.0.0.1');
    }));
    it('should be possible to configure logger', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const fSpy = jest.spyOn(fastify_1.default, 'default');
        fSpy.mockImplementationOnce(() => ({ post: jest.fn() }));
        __1.createPubSubHandler(handler, { fastifyConfig: { logger: true } });
        expect(fSpy).toHaveBeenCalledWith({
            logger: true,
        });
    }));
});
