"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPubSubHandler = exports.PubSubHandlerResponse = exports.PubSubMessage = void 0;
const tslib_1 = require("tslib");
const typebox_1 = require("@sinclair/typebox");
const fastify_1 = require("fastify");
exports.PubSubMessage = typebox_1.Type.Object({
    message: typebox_1.Type.Object({
        attributes: typebox_1.Type.Unknown(),
        data: typebox_1.Type.String(),
        messageId: typebox_1.Type.Optional(typebox_1.Type.String()),
    }),
    subscription: typebox_1.Type.String(),
});
class PubSubHandlerResponse {
}
exports.PubSubHandlerResponse = PubSubHandlerResponse;
function createPubSubHandler(handler, config = {}) {
    const { fastifyConfig, port = process.env.PORT || 8000, address = '0.0.0.0', parseJson = true, } = config;
    const fastify = fastify_1.default(Object.assign({}, fastifyConfig));
    fastify.post('/', {
        schema: {
            body: exports.PubSubMessage,
            response: { 204: {} },
        },
    }, (req, reply) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const decodedMessage = Buffer.from(req.body.message.data, 'base64')
            .toString()
            .trim();
        let data;
        if (parseJson) {
            data = JSON.parse(decodedMessage);
        }
        const res = yield handler({
            message: req.body,
            data: data,
        });
        reply.code((res && res.statusCode) || 204);
        reply.send();
    }));
    return {
        listen() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                yield fastify.listen(port, address);
            });
        },
        fastify,
    };
}
exports.createPubSubHandler = createPubSubHandler;
